# Copyright (c) 2013, 2014 Dave Love, Liverpool University
# MIT licence, per Fedora policy

# fixme: use Debian's makefile patch?

Name:		bowtie2
Version:	2.3.2
Release:	1%{?dist}
Summary:	Fast and sensitive read alignment

License:	GPLv3+
URL:		http://bowtie-bio.sourceforge.net/bowtie2/index.shtml
Source0:	http://downloads.sourceforge.net/bowtie-bio/%{name}/%{version}/%{name}-%{version}-source.zip
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:	gcc-c++ tbb-devel zlib-devel
# 64-bit, sse2-specific
ExclusiveArch:  x86_64
Provides:       bowtie = %version
Obsoletes:      bowtie < 2.0

%description

Bowtie 2 is an ultrafast and memory-efficient tool for aligning
sequencing reads to long reference sequences. It is particularly good
at aligning reads of about 50 up to 100s or 1,000s of characters, and
particularly good at aligning to relatively long (e.g. mammalian)
genomes. Bowtie 2 indexes the genome with an FM Index to keep its
memory footprint small: for the human genome, its memory footprint is
typically around 3.2 GB. Bowtie 2 supports gapped, local, and
paired-end alignment modes.
Please cite:
Langmead B, Salzberg S. Fast gapped-read alignment with Bowtie 2.
Nature Methods. 2012, 9:357-359

%package example
Summary: Example files for %name
BuildArch: noarch
Conflicts: bowtie2 < 2.2.9-2

%description example
Example files for %name

%prep
%setup -q
chmod +x example/reads/simulate.pl


%build
# Specify LIBS because makefile uses -ltbbmalloc_proxy.  BITS=64
# because makefile tests x86 (only).  SSE_FLAG= because makefile uses
# -msse2 (default for x86_64).
make %{?_smp_mflags} BITS=64 WITH_TBB=1 LIBS='-lpthread -ltbb -ltbbmalloc -lz' SSE_FLAG= CXX='g++ -std=gnu++98'


%global __requires_exclude_from ^%_datadir/%name/example
%{?filter_setup:
%filter_requires_in %_datadir/%name/example
%filter_setup
}


%install
rm -rf %{buildroot}
make install DESTDIR=%buildroot prefix=%_prefix
mkdir -p %{buildroot}/%_datadir/%name
cp -a example scripts %{buildroot}/%{_datadir}/%name/
ln -s bowtie2-align-s %{buildroot}/%_bindir/bowtie2-align
chmod 755 example/reads/simulate.pl

%clean
rm -rf %{buildroot}

%check
# fixme: can the example be used sensibly?


%{!?_licensedir:%global license %doc}
%files
%license LICENSE
%doc doc/{style.css,manual.html} AUTHORS NEWS MANUAL TUTORIAL
%_bindir/*
%_datadir/%name
%exclude %_datadir/%name/example

%files example
%license LICENSE
%_datadir/%name/example


%changelog
* Tue Jul 25 2017  <vagrant@localhost.localdomain> - 2.3.2-1
- New version
- Build against zlib

* Wed May 18 2016 Dave Love <loveshack@fedoraproject.org> - 2.2.9-2
- Separate example package
- Filter requires

* Mon May  9 2016 Dave Love <loveshack@fedoraproject.org> - 2.2.9-1
- New version
- Use TBB
- Don't use optflags
- Remove tinythreads stuff
- Modify make args
- Use %%license

* Thu Jan 14 2016 Dave Love <loveshack@fedoraproject.org> - 2.2.6-1
- New version
- Modify patch
- Use make install target
- Don't link the -build and -inspect programs
- Restrict to x86 (for -msse2)

* Mon Mar 30 2015 Dave Love <d.love@liverpool.ac.uk> - 2.2.5-1
- New version

* Mon Dec  1 2014 Dave Love <d.love@liverpool.ac.uk> - 2.2.4-1
- New version

* Wed Jun  4 2014 Dave Love <d.love@liverpool.ac.uk> - 2.2.3-1
- Update to 2.2.3
- Use unbundled libtinythread++ and cpuid.h
- Only for 64-bit architectures
- Obsolete bowtie 1 (bowtie- binaries are included)
- Make compatibility links to small versions

* Wed Jun  4 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1.0-3
- Use unbindled libtinythread++, remove bundled cpuid.h

* Wed Nov 20 2013 Dave Love <d.love@liverpool.ac.uk> - 2.1.0-2
- Include the scripts directory and don't include doc/README
- Note tinythread licence

* Sun May 12 2013 Dave Love <d.love@liverpool.ac.uk> - 2.1.0-1
- Initial version, based on bowtie
